<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs_CZ">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno nebo více zařízení</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Přepnout do okna</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Přepnout na celou obrazovku</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Nastavení proběhlo úspěšně.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Zavřít toto okno a znovu spustit vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Hezkou zábavu s vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno nebo více zařízení</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nebyl nalezen žádný správce souborů.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Prosím o instalaci správce souborů.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Nahrávání nemůže být spuštěno, není dostatek volného místa na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Je dosaženo limitu volného místa na disku.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit volného místa na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Nahrávání bylo zastaveno, není volné místo na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nebyl nalezen žádný správce souborů.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Prosím o instalaci správce souborů.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Překlad</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podpořit</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno nebo více zařízení</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Výřez</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Výřez</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odejít</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odejít</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Překlopit vodorovně</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Překlopit svisle</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovat</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Šedý</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Černá a bílá</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstranit rám okna</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Nastavení kamery</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Výřez</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočítávání</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Velikost videa:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Volné místo na disku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Doba záznamu:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávat kurzor myši</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hodina</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Spustit časovač</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Ukončit nahrávání po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuty</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Cesta k videosekvenci</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit volného místa na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Zobrazit v systémové části panelu</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Druhé čekání před nahráváním</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Vyhledat aktualizace</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostupný</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nedostupný</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Adresář</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovat</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Šedý</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Zaslat report</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Přehrát poslední záznam</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalizovat před začátkem nahrávání</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Spustit minimalizované</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Překlopit vodorovně</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Překlopit svisle</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Černá a bílá</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstranit rám okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podpořit</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Obnovit všechna nastavení při následujícím spuštění</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorská práva a licence k obrázkům</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Nahrávka</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logy</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Vytvořit snímky karet</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informace o licenci</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Globální klávesové zkratky</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Přiřazené klávesové zkratky.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Nepřiřazená nebo více než jednou přiřazená klávesová zkratka.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Pokud je zobrazena jako přiřazená, ale nefunguje, používá ji jiný program.</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorská práva a licence k obrázkům</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Předchozí snímek</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Následující snímek</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Přesunout nabídku</translation>
    </message>
</context>
</TS>